dist2line: Compute perpendicular distances and projections onto line
Description
Calculates perpendicular distances of a point process contained within a strip
to the center line of the strip they are contained in. It also computes the positions
of the objects projected onto the line. This is the inverse of the offset.points function.
Usage
dist2line(object.ppp, line.ends)
Arguments
object.ppp
point process for observations in a strip
line.ends
ends of line x0,y0,x1,y1
Value
distValsvector of perpendicular distances
projectiondataframe of projected locations on the line