lines_to_strips: Convert lines to transects (strips)
Description
Convert lines (center) with transect widths to strips and compute rotation angle
from vertical. With the intersect function in gpclib, it also now clips the portions
of the transects that are outside the study area.Usage
lines_to_strips(lines, study.area, width = NULL)
Value
linesa psp class of lines with label and angles for rotation addedtransectsa list of dataframes with polygon coordinatesDetails
The function assumes that the intersection of the strip and the study area only
results in a single intersection polygon. That means the entire strip cannot pass
outside the study area and then come back into the study area as in an aerial transect
that passes over water to over land and then back over water. In this case, the
line should end when it passes out of the sampled area and restarted when back in the
sampled area.