Learn R Programming

DSpat (version 0.1.0)

weeds.all: Dubbo weed data with constructed y-coordinate

Description

Locations of devils claw in a farming paddock. Locations to all weeds are given as x,y coordinates and are contained in one of eight 150m wide transects (75m each side). The weeds seen by observers are specified as Seen=1.

Usage

data(weeds.all)

Arguments

docType

data

Details

The data provided from Melville and Welsh did not have the y-coordinate. We have constructed y-coordinates by drawing randomly from a uniform distribution in the y-direction such that no two weeds are at the exact same location. The code used to create weeds.all was as follows: data(weeds) # Fudge the data ever so slightly to appease spatstat so the transects don't abut # and all points are contained within the strips. weeds$SignedDistance[weeds$SignedDistance==75]=74.99 weeds$SignedDistance[weeds$SignedDistance==-75]=-74.99 weeds.all=data.frame(label=weeds$Transect, x=(weeds$Transect-1)*150+75 +weeds$SignedDistance, y=floor(runif(dim(weeds)[1])*1200), distance=weeds$Distance, Seen=weeds$Seen) while(any(duplicated(data.frame(x=weeds.all$x,y=weeds.all$y)))) { npts=sum(as.numeric(any(duplicated(data.frame(x=weeds.all$x,y=weeds.all$y))))) weeds.all$y[duplicated(data.frame(x=weeds.all$x,y=weeds.all$y))]= runif(npts)*1200 } save(weeds.all,file="weeds.all.rda") See weeds for more details.

References

Melville, G. J., and A. H. Welsh. 2001. Line transect sampling in small regions. Biometrics 57:1130-1137.