create.covariate.images: Create a list of covariate images
Description
Creates a list of covariates images from a dataframe of covariates
defined on a grid for the study area. Images are created for
variables contained in vector of names varnames and the values of the covariates are
in the covariates dataframe.Usage
create.covariate.images(covariates, varnames)
Value
covariate.im - list of covariate images (class im)