Learn R Programming

DSpat (version 0.1.0)

dist2line: Compute perpendicular distances and projections onto line

Description

Calculates perpendicular distances of a point process contained within a strip to the center line of the strip they are contained in. It also computes the positions of the objects projected onto the line. This is the inverse of the offset.points function.

Usage

dist2line(object.ppp, line.ends)

Arguments

Value

distValsvector of perpendicular distancesprojectiondataframe of projected locations on the line

See Also

project2line